@@ -27,6 +27,7 @@
 ******************************************************************************/
 static gint width,height;
 static GtkWidget *button0,*check0,*check1,*spin0,*spin1,*spin2;
+static GtkWidget *radio0,*radio1,*radio2,*radio3;
 
 
 /* OKܥɽ */
@@ -55,6 +56,14 @@ static void conf_dialog_clicked(GtkWidget *widget,GtkWidget *dialog)
 	second=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check1));
 	def_width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
 	def_height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2));
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio0)))
+		n_pos=GTK_POS_TOP;
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio1)))
+		n_pos=GTK_POS_LEFT;
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio2)))
+		n_pos=GTK_POS_RIGHT;
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio3)))
+		n_pos=GTK_POS_BOTTOM;
 	gtk_widget_destroy(dialog);
 	/*  */
 	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
@@ -63,6 +72,8 @@ static void conf_dialog_clicked(GtkWidget *widget,GtkWidget *dialog)
 	for (i=g_list_length(glist)-3;i>history-(history==0)+MENUFILE-2;i--)
 		gtk_container_remove(GTK_CONTAINER(sub_menu),g_list_nth_data(glist,i));
 	g_list_free(glist);
+	/* ΡȤΰ */
+	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook),n_pos);
 }
 
 
@@ -95,7 +106,7 @@ void conf_dialog(void)
 	guint key;
 	GtkAccelGroup *accel;
 	GtkWidget *dialog,*button1,*label0,*label1,*label2;
-	GtkWidget *frame,*hbox0,*hbox1,*vbox;
+	GtkWidget *frame0,*frame1,*hbox0,*hbox1,*vbox;
 
 	width=gdk_screen_width();
 	height=gdk_screen_height();
@@ -173,8 +184,46 @@ void conf_dialog(void)
 	gtk_widget_add_accelerator(spin2,"grab-focus",accel,key,
 									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
 											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	/* 饸ܥ */
+	radio0=gtk_radio_button_new_with_label(NULL,NULL);
+	radio1=gtk_radio_button_new_with_label_from_widget(
+												GTK_RADIO_BUTTON(radio0),NULL);
+	radio2=gtk_radio_button_new_with_label_from_widget(
+												GTK_RADIO_BUTTON(radio0),NULL);
+	radio3=gtk_radio_button_new_with_label_from_widget(
+												GTK_RADIO_BUTTON(radio0),NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("(_T)"));
+	gtk_widget_add_accelerator(radio0,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("(_L)"));
+	gtk_widget_add_accelerator(radio1,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio2)->child),_("(_R)"));
+	gtk_widget_add_accelerator(radio2,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio3)->child),_("(_B)"));
+	gtk_widget_add_accelerator(radio3,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	switch (n_pos) {
+		case GTK_POS_TOP:	gtk_toggle_button_set_active(
+										GTK_TOGGLE_BUTTON(radio0),TRUE);break;
+		case GTK_POS_LEFT:	gtk_toggle_button_set_active(
+										GTK_TOGGLE_BUTTON(radio1),TRUE);break;
+		case GTK_POS_RIGHT:	gtk_toggle_button_set_active(
+										GTK_TOGGLE_BUTTON(radio2),TRUE);break;
+		case GTK_POS_BOTTOM:gtk_toggle_button_set_active(
+										GTK_TOGGLE_BUTTON(radio3),TRUE);
+	}
+	gtk_signal_connect(GTK_OBJECT(radio0),"toggled",conf_dialog_toggled,NULL);
+	gtk_signal_connect(GTK_OBJECT(radio1),"toggled",conf_dialog_toggled,NULL);
+	gtk_signal_connect(GTK_OBJECT(radio2),"toggled",conf_dialog_toggled,NULL);
+	gtk_signal_connect(GTK_OBJECT(radio3),"toggled",conf_dialog_toggled,NULL);
 	/* ե졼ȥܥå */
-	frame=gtk_frame_new(_("ɥΥ"));
+	frame0=gtk_frame_new(_("ɥΥ"));
 	vbox=gtk_vbox_new(FALSE,0);
 	hbox0=gtk_hbox_new(FALSE,0);
 	hbox1=gtk_hbox_new(FALSE,0);
@@ -186,7 +235,21 @@ void conf_dialog(void)
 	gtk_box_pack_start(GTK_BOX(hbox1),spin2,TRUE,TRUE,0);
 	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,8);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
-	gtk_container_add(GTK_CONTAINER(frame),vbox);
+	gtk_container_add(GTK_CONTAINER(frame0),vbox);
+
+	frame1=gtk_frame_new(_("֤ΰ"));
+	vbox=gtk_vbox_new(FALSE,0);
+	hbox0=gtk_hbox_new(FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox0),radio0,TRUE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	hbox0=gtk_hbox_new(FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox0),radio1,FALSE,FALSE,8);
+	gtk_box_pack_end(GTK_BOX(hbox0),radio2,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	hbox0=gtk_hbox_new(FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox0),radio3,TRUE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	gtk_container_add(GTK_CONTAINER(frame1),vbox);
 
 	vbox=gtk_vbox_new(FALSE,0);
 	hbox0=gtk_hbox_new(FALSE,0);
@@ -202,11 +265,23 @@ void conf_dialog(void)
 	gtk_box_pack_start(GTK_BOX(hbox0),check1,FALSE,FALSE,8);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
 	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),frame,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox0),frame0,TRUE,TRUE,8);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+
+	hbox1=gtk_hbox_new(FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox1),vbox,TRUE,TRUE,8);
+
+	vbox=gtk_vbox_new(FALSE,0);
+	hbox0=gtk_hbox_new(FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox0),frame1,TRUE,TRUE,8);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox1),vbox,TRUE,TRUE,8);
+
+	vbox=gtk_vbox_new(FALSE,0);
 	hbox0=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox0),button1,FALSE,FALSE,8);
 	gtk_box_pack_end(GTK_BOX(hbox0),button0,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox1,TRUE,TRUE,8);
 	gtk_box_pack_end(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
 	gtk_container_add(GTK_CONTAINER(dialog),vbox);
 
