@@ -519,9 +519,9 @@ gboolean property_dialog(FTYPE *ft)
 											property_dialog_unselect_row,NULL);
 	/* 륦ɥ */
 	scroll=gtk_scrolled_window_new(NULL,NULL);
+	gtk_container_add(GTK_CONTAINER(scroll),clist);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
 										GTK_POLICY_NEVER,GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scroll),clist);
 	/* ԥܥ */
 	spin0=gtk_spin_button_new(
 		GTK_ADJUSTMENT(gtk_adjustment_new(ft->margin,1,G_MAXINT,1,5,0)),0,0);
