@@ -374,10 +374,10 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 			if (caret && GTK_WIDGET_HAS_FOCUS(widget)
 								&& cursor.x==ptw->top.x+x/ptw->fontsize
 								&& cursor.y==ptw->top.y+y/(ptw->fontsize*2)) {
-				gdk_gc_set_foreground(gc,
-						(ptw->syscol?system_color:ptw->color)+(select?8:0));
+				gdk_gc_set_function(gc,GDK_INVERT);
 				gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
 										ins?2:ptw->fontsize,ptw->fontsize*2);
+				gdk_gc_set_function(gc,GDK_COPY);
 			}
 			x+=width;
 		}
@@ -421,11 +421,10 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 		if (caret && GTK_WIDGET_HAS_FOCUS(widget)
 								&& cursor.x==ptw->top.x+x/ptw->fontsize
 								&& cursor.y==ptw->top.y+y/(ptw->fontsize*2)) {
-			gdk_gc_set_foreground(gc,(ptw->syscol?system_color:ptw->color)
-						+(start.x>=0 && start.y<=ptw->top.y+y/(ptw->fontsize*2)
-								&& ptw->top.y+y/(ptw->fontsize*2)<end.y?8:0));
+			gdk_gc_set_function(gc,GDK_INVERT);
 			gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
 										ins?2:ptw->fontsize,ptw->fontsize*2);
+			gdk_gc_set_function(gc,GDK_COPY);
 		}
 	}
 
@@ -1172,16 +1171,16 @@ void signal_style_set(GtkWidget *widget,GtkStyle *style,gpointer user_data)
 	TEXTWND *ptw;
 
 	style=gtk_widget_get_style(widget);
-	system_color[ 0]=style->text[0];
-	system_color[ 1]=style->base[0];
-	system_color[ 2]=style->dark[0];
-	system_color[ 3]=style->dark[0];
-	system_color[ 4]=style->dark[0];
-	system_color[ 5]=style->dark[0];
-	system_color[ 6]=style->dark[0];
-	system_color[ 7]=style->mid[0];
-	system_color[ 8]=style->fg[3];
-	system_color[ 9]=style->bg[3];
+	system_color[0]=style->text[0];
+	system_color[1]=style->base[0];
+	system_color[2]=style->dark[0];
+	system_color[3]=style->dark[0];
+	system_color[4]=style->dark[0];
+	system_color[5]=style->dark[0];
+	system_color[6]=style->dark[0];
+	system_color[7]=style->mid[0];
+	system_color[8]=style->fg[3];
+	system_color[9]=style->bg[3];
 	glist=gtk_container_children(GTK_CONTAINER(notebook));
 	for (i=g_list_length(glist)-1;i>=0;i--) {
 		ptw=gtk_object_get_user_data(GTK_OBJECT(g_list_nth_data(glist,i)));
