@@ -59,6 +59,7 @@ GdkAtom atom_textmaid;				/* ץ̿ѥȥ */
 GtkWidget *window;					/* ɥ */
 GtkWidget *notebook;				/* Ρȥ֥å */
 GtkWidget *status;					/* ơɥ */
+GtkPositionType n_pos=GTK_POS_TOP;	/* Ρȥ֥åΰ */
 GtkItemFactory *item_factory_menu;	/* ˥塼 */
 GtkItemFactory *item_factory_popup;	/* ݥåץå */
 GdkColor system_color[12]={	{0,0x0000,0x0000,0x0000},{0,0xffff,0xffff,0xffff},
@@ -136,7 +137,7 @@ int main(int argc,char *argv[])
 {N_("/Žդ(_P)"),                               "<control>V", command_paste,   0,"<Item>"},
 {N_("/(_L)"),                                   NULL,         command_delete,  0,"<Item>"},
 {N_("/Sep2"),                                       NULL,         NULL,            0,"<Separator>"},
-{N_("/٤(_A)"),"<control>A",command_all,   0,"<Item>"}};
+{N_("/٤(_A)"),                             "<control>A", command_all,     0,"<Item>"}};
 	/* Drag&Drop */
 	GtkTargetEntry drag_types[1]={{"text/uri-list",0,0}};
 	/* Text maid󶡲ǽʥ쥯 */
@@ -191,6 +192,9 @@ int main(int argc,char *argv[])
 		if (!profile_get_value(profile,"tmaid","def_height",
 				(gpointer)&def_height,sizeof(gint),PROFILE_VALUE_TYPE_INT))
 			def_height=gdk_screen_height()*2/3;
+		if (!profile_get_value(profile,"tmaid","n_pos",
+				(gpointer)&n_pos,sizeof(gint),PROFILE_VALUE_TYPE_INT))
+			n_pos=GTK_POS_TOP;
 		/* ե */
 		for (i=0;i<history;i++) {
 			key=g_strdup_printf("history%d",i);
@@ -493,6 +497,7 @@ int main(int argc,char *argv[])
 	/* Ρȥ֥å */
 	notebook=gtk_notebook_new();
 	gtk_notebook_set_scrollable(GTK_NOTEBOOK(notebook),TRUE);
+	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook),n_pos);
 	gtk_signal_connect(GTK_OBJECT(notebook),"switch-page",
 								GTK_SIGNAL_FUNC(signal_switch_page),NULL);
 	gtk_signal_connect(GTK_OBJECT(notebook),"destroy",
@@ -532,11 +537,11 @@ int main(int argc,char *argv[])
 	/* ľܥå/ϥɥܥå */
 	vbox=gtk_vbox_new(FALSE,0);
 	handle=gtk_handle_box_new();
-	gtk_container_set_border_width (GTK_CONTAINER(handle),2);
+	gtk_container_set_border_width(GTK_CONTAINER(handle),2);
 	gtk_container_add(GTK_CONTAINER(handle),menubar);
 	gtk_box_pack_start(GTK_BOX(vbox),handle,FALSE,FALSE,0);
 	handle=gtk_handle_box_new();
-	gtk_container_set_border_width (GTK_CONTAINER(handle),2);
+	gtk_container_set_border_width(GTK_CONTAINER(handle),2);
 	gtk_container_add(GTK_CONTAINER(handle),toolbar);
 	gtk_box_pack_start(GTK_BOX(vbox),handle,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(vbox),notebook,TRUE,TRUE,0);
@@ -606,27 +611,28 @@ int main(int argc,char *argv[])
 
 	/* ƥ࿧ */
 	style=gtk_widget_get_style(text);
-	system_color[ 0]=style->text[0];
-	system_color[ 1]=style->base[0];
-	system_color[ 2]=style->dark[0];
-	system_color[ 3]=style->dark[0];
-	system_color[ 4]=style->dark[0];
-	system_color[ 5]=style->dark[0];
-	system_color[ 6]=style->dark[0];
-	system_color[ 7]=style->mid[0];
-	system_color[ 8]=style->fg[3];
-	system_color[ 9]=style->bg[3];
+	system_color[0]=style->text[0];
+	system_color[1]=style->base[0];
+	system_color[2]=style->dark[0];
+	system_color[3]=style->dark[0];
+	system_color[4]=style->dark[0];
+	system_color[5]=style->dark[0];
+	system_color[6]=style->dark[0];
+	system_color[7]=style->mid[0];
+	system_color[8]=style->fg[3];
+	system_color[9]=style->bg[3];
 
 	/* ɥ */
+	j=0;
 	for (i=1;i<argc;i++)
 		if (arg_files[i]) {
 			ptw=open_edit_file(argv[i]);
 			if (init_line!=0)	/* Ԥ˰ư */
 				jump_operation(ptw,init_line);
-			newfile=FALSE;
+			j++;
 		}
 	g_free(arg_files);
-	if (newfile)
+	if (newfile && j<=0)
 		open_edit_file(NULL);
 
 	gtk_main();
@@ -645,6 +651,8 @@ int main(int argc,char *argv[])
 				(gpointer)&def_width,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"tmaid","def_height",
 				(gpointer)&def_height,sizeof(gint),PROFILE_VALUE_TYPE_INT);
+		profile_set_value(profile,"tmaid","n_pos",
+				(gpointer)&n_pos,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		/* ե */
 		for (i=0;i<history && hisfile[i]!=NULL;i++) {
 			key=g_strdup_printf("history%d",i);
