@@ -93,7 +93,7 @@ static gboolean valchr_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 gboolean valchr_dialog(gchar *valchr)
 {
 	gchar *text;
-	GSList *group=NULL;
+	guint key;
 	GtkAccelGroup *accel;
 	GtkWidget *button1,*radio0,*radio1,*radio2,*frame,*hbox,*vbox;
 
@@ -103,6 +103,9 @@ gboolean valchr_dialog(gchar *valchr)
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 								GTK_SIGNAL_FUNC(valchr_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
 	/* ܥ */
 	button0=gtk_button_new_with_label(_("λ"));
 	button1=gtk_button_new_with_label(_(""));
@@ -119,11 +122,26 @@ gboolean valchr_dialog(gchar *valchr)
 												valchr_dialog_activate,valchr);
 	gtk_signal_connect(GTK_OBJECT(entry),"changed",valchr_dialog_changed,NULL);
 	/* 饸ܥ */
-	radio0=gtk_radio_button_new_with_label(group,_("16ʿ"));
-	group=gtk_radio_button_group(GTK_RADIO_BUTTON(radio0));
-	radio1=gtk_radio_button_new_with_label(group,_("10ʿ"));
-	group=gtk_radio_button_group(GTK_RADIO_BUTTON(radio1));
-	radio2=gtk_radio_button_new_with_label(group,_("8ʿ"));
+	radio0=gtk_radio_button_new_with_label(NULL,NULL);
+	radio1=gtk_radio_button_new_with_label_from_widget(
+												GTK_RADIO_BUTTON(radio0),NULL);
+	radio2=gtk_radio_button_new_with_label_from_widget(
+												GTK_RADIO_BUTTON(radio1),NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),
+															_("16ʿ(_H)"));
+	gtk_widget_add_accelerator(radio0,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),
+															_("10ʿ(_T)"));
+	gtk_widget_add_accelerator(radio1,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio2)->child),
+															_("8ʿ(_Q)"));
+	gtk_widget_add_accelerator(radio2,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
 	switch (valchr_base) {
 	case 16:gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio0),TRUE);break;
 	case 10:gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio1),TRUE);break;
@@ -135,21 +153,6 @@ gboolean valchr_dialog(gchar *valchr)
 									valchr_dialog_clicked_radio,(gpointer)10);
 	gtk_signal_connect(GTK_OBJECT(radio2),"clicked",
 									valchr_dialog_clicked_radio,(gpointer)8);
-	/* 졼 */
-	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
-	gtk_widget_add_accelerator(radio0,"clicked",accel,'H',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(radio0)->child,'H');
-	gtk_widget_add_accelerator(radio1,"clicked",accel,'T',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(radio1)->child,'T');
-	gtk_widget_add_accelerator(radio2,"clicked",accel,'Q',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(radio2)->child,'Q');
 	/* ե졼ȥܥå */
 	frame=gtk_frame_new(_(""));
 	vbox=gtk_vbox_new(FALSE,0);
